# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/yamcsManagement/yamcsManagement.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/yamcsManagement/yamcsManagement.proto',
  package='yamcs.protobuf.yamcsManagement',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\024YamcsManagementProtoP\001'),
  serialized_pb=_b('\n4yamcs/protobuf/yamcsManagement/yamcsManagement.proto\x12\x1eyamcs.protobuf.yamcsManagement\x1a\x1ayamcs/protobuf/yamcs.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\"Q\n\x0eYamcsInstances\x12?\n\x08instance\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.YamcsInstance\"\x84\x04\n\rYamcsInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0fmissionDatabase\x18\x03 \x01(\x0b\x32#.yamcs.protobuf.mdb.MissionDatabase\x12@\n\tprocessor\x18\x04 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\x12J\n\x05state\x18\x0b \x01(\x0e\x32;.yamcs.protobuf.yamcsManagement.YamcsInstance.InstanceState\x12\x14\n\x0c\x66\x61ilureCause\x18\t \x01(\t\x12\x13\n\x0bmissionTime\x18\n \x01(\t\x12I\n\x06labels\x18\x0c \x03(\x0b\x32\x39.yamcs.protobuf.yamcsManagement.YamcsInstance.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\rInstanceState\x12\x0b\n\x07OFFLINE\x10\x00\x12\x10\n\x0cINITIALIZING\x10\x01\x12\x0f\n\x0bINITIALIZED\x10\x02\x12\x0c\n\x08STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\"d\n\x10InstanceTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x08variable\x18\x02 \x03(\x0b\x32\x30.yamcs.protobuf.yamcsManagement.TemplateVariable\"G\n\x10TemplateVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\"\xa8\x03\n\rProcessorInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04spec\x18\x04 \x01(\t\x12\x0f\n\x07\x63reator\x18\x05 \x01(\t\x12\x11\n\thasAlarms\x18\x06 \x01(\x08\x12\x15\n\rhasCommanding\x18\x07 \x01(\x08\x12;\n\x05state\x18\x08 \x01(\x0e\x32,.yamcs.protobuf.yamcsManagement.ServiceState\x12\x34\n\rreplayRequest\x18\t \x01(\x0b\x32\x1d.yamcs.protobuf.ReplayRequest\x12=\n\x0breplayState\x18\n \x01(\x0e\x32(.yamcs.protobuf.ReplayStatus.ReplayState\x12<\n\x07service\x18\x10 \x03(\x0b\x32+.yamcs.protobuf.yamcsManagement.ServiceInfo\x12\x12\n\npersistent\x18\x11 \x01(\x08\x12\x0c\n\x04time\x18\x12 \x01(\t\x12\x0e\n\x06replay\x18\x13 \x01(\x08\"\xaf\x02\n\nClientInfo\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x17\n\x0f\x61pplicationName\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\n \x01(\t\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x15\n\rprocessorName\x18\x05 \x01(\t\x12\x45\n\x05state\x18\x06 \x01(\x0e\x32\x36.yamcs.protobuf.yamcsManagement.ClientInfo.ClientState\x12-\n\tloginTime\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x0b\x43lientState\x12\r\n\tCONNECTED\x10\x00\x12\x10\n\x0c\x44ISCONNECTED\x10\x01J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\xf2\x01\n\x0cTmStatistics\x12\x12\n\npacketName\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\t \x01(\t\x12\x17\n\x0freceivedPackets\x18\x02 \x01(\x03\x12 \n\x18subscribedParameterCount\x18\x06 \x01(\x05\x12\x30\n\x0clastReceived\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elastPacketTime\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"\xb2\x01\n\nStatistics\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x16\n\x0eyProcessorName\x18\x02 \x01(\t\x12=\n\x07tmstats\x18\x03 \x03(\x0b\x32,.yamcs.protobuf.yamcsManagement.TmStatistics\x12/\n\x0blastUpdated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"\x9d\x02\n\x1aProcessorManagementRequest\x12W\n\toperation\x18\x01 \x01(\x0e\x32\x44.yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.Operation\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x10\n\x08\x63lientId\x18\x06 \x03(\x05\x12\x19\n\npersistent\x18\x07 \x01(\x08:\x05\x66\x61lse\";\n\tOperation\x12\x14\n\x10\x43REATE_PROCESSOR\x10\x00\x12\x18\n\x14\x43ONNECT_TO_PROCESSOR\x10\x01\"\x85\x02\n\x10ProcessorRequest\x12M\n\toperation\x18\x01 \x01(\x0e\x32:.yamcs.protobuf.yamcsManagement.ProcessorRequest.Operation\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08seekTime\x18\x04 \x01(\x03\x12\x30\n\x0breplaySpeed\x18\x05 \x01(\x0b\x32\x1b.yamcs.protobuf.ReplaySpeed\">\n\tOperation\x12\t\n\x05PAUSE\x10\x02\x12\n\n\x06RESUME\x10\x03\x12\x08\n\x04SEEK\x10\x04\x12\x10\n\x0c\x43HANGE_SPEED\x10\x05\"\xcb\x01\n\x08LinkInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04spec\x18\x04 \x01(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x0e\n\x06status\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x61taInCount\x18\n \x01(\x03\x12\x14\n\x0c\x64\x61taOutCount\x18\x0b \x01(\x03\x12\x16\n\x0e\x64\x65tailedStatus\x18\t \x01(\t\x12\x12\n\nparentName\x18\x0c \x01(\tJ\x04\x08\x05\x10\x06J\x04\x08\x08\x10\t\"\xbc\x01\n\tLinkEvent\x12<\n\x04type\x18\x01 \x01(\x0e\x32..yamcs.protobuf.yamcsManagement.LinkEvent.Type\x12:\n\x08linkInfo\x18\x02 \x01(\x0b\x32(.yamcs.protobuf.yamcsManagement.LinkInfo\"5\n\x04Type\x12\x0e\n\nREGISTERED\x10\x01\x12\x10\n\x0cUNREGISTERED\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\"\x90\x01\n\x0bServiceInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\x05state\x18\x03 \x01(\x0e\x32,.yamcs.protobuf.yamcsManagement.ServiceState\x12\x11\n\tclassName\x18\x04 \x01(\t\x12\x11\n\tprocessor\x18\x05 \x01(\t\"\x9d\x01\n\x0bStreamEvent\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.yamcs.protobuf.yamcsManagement.StreamEvent.Type\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdataCount\x18\x03 \x01(\x03\"-\n\x04Type\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07\x44\x45LETED\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\"\x80\x04\n\nSystemInfo\x12\x14\n\x0cyamcsVersion\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x02 \x01(\t\x12\x10\n\x08serverId\x18\x03 \x01(\t\x12\x0e\n\x06uptime\x18\x05 \x01(\x03\x12\x0b\n\x03jvm\x18\x06 \x01(\t\x12\x18\n\x10workingDirectory\x18\x07 \x01(\t\x12\x17\n\x0f\x63onfigDirectory\x18\x08 \x01(\t\x12\x15\n\rdataDirectory\x18\t \x01(\t\x12\x16\n\x0e\x63\x61\x63heDirectory\x18\n \x01(\t\x12\n\n\x02os\x18\x0b \x01(\t\x12\x0c\n\x04\x61rch\x18\x0c \x01(\t\x12\x1b\n\x13\x61vailableProcessors\x18\r \x01(\x05\x12\x13\n\x0bloadAverage\x18\x0e \x01(\x01\x12\x12\n\nheapMemory\x18\x0f \x01(\x03\x12\x16\n\x0eusedHeapMemory\x18\x10 \x01(\x03\x12\x15\n\rmaxHeapMemory\x18\x11 \x01(\x03\x12\x15\n\rnonHeapMemory\x18\x12 \x01(\x03\x12\x19\n\x11usedNonHeapMemory\x18\x13 \x01(\x03\x12\x18\n\x10maxNonHeapMemory\x18\x14 \x01(\x03\x12\x16\n\x0ejvmThreadCount\x18\x15 \x01(\x03\x12\x46\n\x0frootDirectories\x18\x16 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.RootDirectory\"s\n\rRootDirectory\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\ntotalSpace\x18\x03 \x01(\x03\x12\x18\n\x10unallocatedSpace\x18\x04 \x01(\x03\x12\x13\n\x0busableSpace\x18\x05 \x01(\x03\"\'\n\x13ListServicesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"3\n\x11GetServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x13StartServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"4\n\x12StopServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x14ListServicesResponse\x12=\n\x08services\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.yamcsManagement.ServiceInfo\"&\n\x14ListInstancesRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x03(\t\"Y\n\x15ListInstancesResponse\x12@\n\tinstances\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.YamcsInstance\"\xcd\x02\n\x15\x43reateInstanceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08template\x18\x02 \x01(\t\x12]\n\x0ctemplateArgs\x18\x03 \x03(\x0b\x32G.yamcs.protobuf.yamcsManagement.CreateInstanceRequest.TemplateArgsEntry\x12Q\n\x06labels\x18\x04 \x03(\x0b\x32\x41.yamcs.protobuf.yamcsManagement.CreateInstanceRequest.LabelsEntry\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x1dListInstanceTemplatesResponse\x12\x43\n\ttemplates\x18\x01 \x03(\x0b\x32\x30.yamcs.protobuf.yamcsManagement.InstanceTemplate\"6\n\x13\x45\x64itInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"\xbc\x01\n\x10LeapSecondsTable\x12N\n\x06ranges\x18\x01 \x03(\x0b\x32>.yamcs.protobuf.yamcsManagement.LeapSecondsTable.ValidityRange\x1aX\n\rValidityRange\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\x13\n\x0bleapSeconds\x18\x03 \x01(\x05\x12\x15\n\rtaiDifference\x18\x04 \x01(\x05\".\n\x1aGetInstanceTemplateRequest\x12\x10\n\x08template\x18\x01 \x01(\t\"&\n\x12GetInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"(\n\x14StartInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\'\n\x13StopInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"*\n\x16RestartInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"$\n\x10ListLinksRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"L\n\x11ListLinksResponse\x12\x37\n\x05links\x18\x01 \x03(\x0b\x32(.yamcs.protobuf.yamcsManagement.LinkInfo\"0\n\x0eGetLinkRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\x0f\x45\x64itLinkRequest\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05state\x18\x01 \x01(\t\x12\x15\n\rresetCounters\x18\x02 \x01(\x08*\\\n\x0cServiceState\x12\x07\n\x03NEW\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0e\n\nTERMINATED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x32\xb6\x13\n\rManagementApi\x12g\n\rGetSystemInfo\x12\x16.google.protobuf.Empty\x1a*.yamcs.protobuf.yamcsManagement.SystemInfo\"\x12\x8a\x92\x03\x0e\n\x0c/api/sysinfo\x12s\n\x0eGetLeapSeconds\x12\x16.google.protobuf.Empty\x1a\x30.yamcs.protobuf.yamcsManagement.LeapSecondsTable\"\x17\x8a\x92\x03\x13\n\x11/api/leap-seconds\x12\x8d\x01\n\x15ListInstanceTemplates\x12\x16.google.protobuf.Empty\x1a=.yamcs.protobuf.yamcsManagement.ListInstanceTemplatesResponse\"\x1d\x8a\x92\x03\x19\n\x17/api/instance-templates\x12\xad\x01\n\x13GetInstanceTemplate\x12:.yamcs.protobuf.yamcsManagement.GetInstanceTemplateRequest\x1a\x30.yamcs.protobuf.yamcsManagement.InstanceTemplate\"(\x8a\x92\x03$\n\"/api/instance-templates/{template}\x12\x92\x01\n\rListInstances\x12\x34.yamcs.protobuf.yamcsManagement.ListInstancesRequest\x1a\x35.yamcs.protobuf.yamcsManagement.ListInstancesResponse\"\x14\x8a\x92\x03\x10\n\x0e/api/instances\x12\x91\x01\n\x0bGetInstance\x12\x32.yamcs.protobuf.yamcsManagement.GetInstanceRequest\x1a-.yamcs.protobuf.yamcsManagement.YamcsInstance\"\x1f\x8a\x92\x03\x1b\n\x19/api/instances/{instance}\x12\x8f\x01\n\x0e\x43reateInstance\x12\x35.yamcs.protobuf.yamcsManagement.CreateInstanceRequest\x1a-.yamcs.protobuf.yamcsManagement.YamcsInstance\"\x17\x8a\x92\x03\x13\x1a\x0e/api/instances:\x01*\x12\x9b\x01\n\rStartInstance\x12\x34.yamcs.protobuf.yamcsManagement.StartInstanceRequest\x1a-.yamcs.protobuf.yamcsManagement.YamcsInstance\"%\x8a\x92\x03!\x1a\x1f/api/instances/{instance}:start\x12\x98\x01\n\x0cStopInstance\x12\x33.yamcs.protobuf.yamcsManagement.StopInstanceRequest\x1a-.yamcs.protobuf.yamcsManagement.YamcsInstance\"$\x8a\x92\x03 \x1a\x1e/api/instances/{instance}:stop\x12\xa1\x01\n\x0fRestartInstance\x12\x36.yamcs.protobuf.yamcsManagement.RestartInstanceRequest\x1a-.yamcs.protobuf.yamcsManagement.YamcsInstance\"\'\x8a\x92\x03#\x1a!/api/instances/{instance}:restart\x12\x99\x01\n\x0cListServices\x12\x33.yamcs.protobuf.yamcsManagement.ListServicesRequest\x1a\x34.yamcs.protobuf.yamcsManagement.ListServicesResponse\"\x1e\x8a\x92\x03\x1a\n\x18/api/services/{instance}\x12\x93\x01\n\nGetService\x12\x31.yamcs.protobuf.yamcsManagement.GetServiceRequest\x1a+.yamcs.protobuf.yamcsManagement.ServiceInfo\"%\x8a\x92\x03!\n\x1f/api/services/{instance}/{name}\x12\x88\x01\n\x0cStartService\x12\x33.yamcs.protobuf.yamcsManagement.StartServiceRequest\x1a\x16.google.protobuf.Empty\"+\x8a\x92\x03\'\x1a%/api/services/{instance}/{name}:start\x12\x85\x01\n\x0bStopService\x12\x32.yamcs.protobuf.yamcsManagement.StopServiceRequest\x1a\x16.google.protobuf.Empty\"*\x8a\x92\x03&\x1a$/api/services/{instance}/{name}:stop\x12\x8e\x01\n\tListLinks\x12\x30.yamcs.protobuf.yamcsManagement.ListLinksRequest\x1a\x31.yamcs.protobuf.yamcsManagement.ListLinksResponse\"\x1c\x8a\x92\x03\x18\n\x16/api/links/{instance?}\x12\x87\x01\n\x07GetLink\x12..yamcs.protobuf.yamcsManagement.GetLinkRequest\x1a(.yamcs.protobuf.yamcsManagement.LinkInfo\"\"\x8a\x92\x03\x1e\n\x1c/api/links/{instance}/{name}\x12\x8e\x01\n\nUpdateLink\x12/.yamcs.protobuf.yamcsManagement.EditLinkRequest\x1a(.yamcs.protobuf.yamcsManagement.LinkInfo\"%\x8a\x92\x03!*\x1c/api/links/{instance}/{name}:\x01*B,\n\x12org.yamcs.protobufB\x14YamcsManagementProtoP\x01')
  ,
  dependencies=[yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_SERVICESTATE = _descriptor.EnumDescriptor(
  name='ServiceState',
  full_name='yamcs.protobuf.yamcsManagement.ServiceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TERMINATED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5637,
  serialized_end=5729,
)
_sym_db.RegisterEnumDescriptor(_SERVICESTATE)

ServiceState = enum_type_wrapper.EnumTypeWrapper(_SERVICESTATE)
NEW = 0
STARTING = 1
RUNNING = 2
STOPPING = 3
TERMINATED = 4
FAILED = 5


_YAMCSINSTANCE_INSTANCESTATE = _descriptor.EnumDescriptor(
  name='InstanceState',
  full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.InstanceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFFLINE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=721,
  serialized_end=837,
)
_sym_db.RegisterEnumDescriptor(_YAMCSINSTANCE_INSTANCESTATE)

_CLIENTINFO_CLIENTSTATE = _descriptor.EnumDescriptor(
  name='ClientState',
  full_name='yamcs.protobuf.yamcsManagement.ClientInfo.ClientState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONNECTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1687,
  serialized_end=1733,
)
_sym_db.RegisterEnumDescriptor(_CLIENTINFO_CLIENTSTATE)

_PROCESSORMANAGEMENTREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATE_PROCESSOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECT_TO_PROCESSOR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2400,
  serialized_end=2459,
)
_sym_db.RegisterEnumDescriptor(_PROCESSORMANAGEMENTREQUEST_OPERATION)

_PROCESSORREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PAUSE', index=0, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=1, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEEK', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_SPEED', index=3, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2661,
  serialized_end=2723,
)
_sym_db.RegisterEnumDescriptor(_PROCESSORREQUEST_OPERATION)

_LINKEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.yamcsManagement.LinkEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REGISTERED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNREGISTERED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATED', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3067,
  serialized_end=3120,
)
_sym_db.RegisterEnumDescriptor(_LINKEVENT_TYPE)

_STREAMEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.yamcsManagement.StreamEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATED', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3382,
  serialized_end=3427,
)
_sym_db.RegisterEnumDescriptor(_STREAMEVENT_TYPE)


_YAMCSINSTANCES = _descriptor.Descriptor(
  name='YamcsInstances',
  full_name='yamcs.protobuf.yamcsManagement.YamcsInstances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.YamcsInstances.instance', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=318,
)


_YAMCSINSTANCE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=719,
)

_YAMCSINSTANCE = _descriptor.Descriptor(
  name='YamcsInstance',
  full_name='yamcs.protobuf.yamcsManagement.YamcsInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionDatabase', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.missionDatabase', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.processor', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.state', index=3,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureCause', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.failureCause', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionTime', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.missionTime', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.labels', index=6,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_YAMCSINSTANCE_LABELSENTRY, ],
  enum_types=[
    _YAMCSINSTANCE_INSTANCESTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=837,
)


_INSTANCETEMPLATE = _descriptor.Descriptor(
  name='InstanceTemplate',
  full_name='yamcs.protobuf.yamcsManagement.InstanceTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.InstanceTemplate.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variable', full_name='yamcs.protobuf.yamcsManagement.InstanceTemplate.variable', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=939,
)


_TEMPLATEVARIABLE = _descriptor.Descriptor(
  name='TemplateVariable',
  full_name='yamcs.protobuf.yamcsManagement.TemplateVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.TemplateVariable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.yamcsManagement.TemplateVariable.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required', full_name='yamcs.protobuf.yamcsManagement.TemplateVariable.required', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=941,
  serialized_end=1012,
)


_PROCESSORINFO = _descriptor.Descriptor(
  name='ProcessorInfo',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.spec', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.creator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasAlarms', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.hasAlarms', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasCommanding', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.hasCommanding', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.state', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replayRequest', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replayRequest', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replayState', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replayState', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.service', index=10,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.persistent', index=11,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.time', index=12,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replay', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replay', index=13,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1439,
)


_CLIENTINFO = _descriptor.Descriptor(
  name='ClientInfo',
  full_name='yamcs.protobuf.yamcsManagement.ClientInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.id', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.username', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='applicationName', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.applicationName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.address', index=3,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.instance', index=4,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorName', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.processorName', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.state', index=6,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loginTime', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.loginTime', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTINFO_CLIENTSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1745,
)


_TMSTATISTICS = _descriptor.Descriptor(
  name='TmStatistics',
  full_name='yamcs.protobuf.yamcsManagement.TmStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packetName', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.packetName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.qualifiedName', index=1,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receivedPackets', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.receivedPackets', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribedParameterCount', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.subscribedParameterCount', index=3,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastReceived', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastReceived', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastPacketTime', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastPacketTime', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1748,
  serialized_end=1990,
)


_STATISTICS = _descriptor.Descriptor(
  name='Statistics',
  full_name='yamcs.protobuf.yamcsManagement.Statistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.Statistics.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yProcessorName', full_name='yamcs.protobuf.yamcsManagement.Statistics.yProcessorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmstats', full_name='yamcs.protobuf.yamcsManagement.Statistics.tmstats', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastUpdated', full_name='yamcs.protobuf.yamcsManagement.Statistics.lastUpdated', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1993,
  serialized_end=2171,
)


_PROCESSORMANAGEMENTREQUEST = _descriptor.Descriptor(
  name='ProcessorManagementRequest',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.config', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.clientId', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.persistent', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSORMANAGEMENTREQUEST_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2459,
)


_PROCESSORREQUEST = _descriptor.Descriptor(
  name='ProcessorRequest',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seekTime', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.seekTime', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replaySpeed', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.replaySpeed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSORREQUEST_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2462,
  serialized_end=2723,
)


_LINKINFO = _descriptor.Descriptor(
  name='LinkInfo',
  full_name='yamcs.protobuf.yamcsManagement.LinkInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.spec', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.disabled', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.status', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataInCount', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.dataInCount', index=6,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataOutCount', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.dataOutCount', index=7,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detailedStatus', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.detailedStatus', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentName', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.parentName', index=9,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2929,
)


_LINKEVENT = _descriptor.Descriptor(
  name='LinkEvent',
  full_name='yamcs.protobuf.yamcsManagement.LinkEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.LinkEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkInfo', full_name='yamcs.protobuf.yamcsManagement.LinkEvent.linkInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LINKEVENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2932,
  serialized_end=3120,
)


_SERVICEINFO = _descriptor.Descriptor(
  name='ServiceInfo',
  full_name='yamcs.protobuf.yamcsManagement.ServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='className', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.className', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.processor', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3123,
  serialized_end=3267,
)


_STREAMEVENT = _descriptor.Descriptor(
  name='StreamEvent',
  full_name='yamcs.protobuf.yamcsManagement.StreamEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.StreamEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.StreamEvent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataCount', full_name='yamcs.protobuf.yamcsManagement.StreamEvent.dataCount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMEVENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3270,
  serialized_end=3427,
)


_SYSTEMINFO = _descriptor.Descriptor(
  name='SystemInfo',
  full_name='yamcs.protobuf.yamcsManagement.SystemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yamcsVersion', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.yamcsVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.revision', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.serverId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uptime', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.uptime', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jvm', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.jvm', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workingDirectory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.workingDirectory', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='configDirectory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.configDirectory', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataDirectory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.dataDirectory', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cacheDirectory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.cacheDirectory', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.os', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arch', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.arch', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='availableProcessors', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.availableProcessors', index=11,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loadAverage', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.loadAverage', index=12,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heapMemory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.heapMemory', index=13,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedHeapMemory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.usedHeapMemory', index=14,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxHeapMemory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.maxHeapMemory', index=15,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonHeapMemory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.nonHeapMemory', index=16,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedNonHeapMemory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.usedNonHeapMemory', index=17,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNonHeapMemory', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.maxNonHeapMemory', index=18,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jvmThreadCount', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.jvmThreadCount', index=19,
      number=21, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rootDirectories', full_name='yamcs.protobuf.yamcsManagement.SystemInfo.rootDirectories', index=20,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3430,
  serialized_end=3942,
)


_ROOTDIRECTORY = _descriptor.Descriptor(
  name='RootDirectory',
  full_name='yamcs.protobuf.yamcsManagement.RootDirectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='directory', full_name='yamcs.protobuf.yamcsManagement.RootDirectory.directory', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.RootDirectory.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSpace', full_name='yamcs.protobuf.yamcsManagement.RootDirectory.totalSpace', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unallocatedSpace', full_name='yamcs.protobuf.yamcsManagement.RootDirectory.unallocatedSpace', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usableSpace', full_name='yamcs.protobuf.yamcsManagement.RootDirectory.usableSpace', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3944,
  serialized_end=4059,
)


_LISTSERVICESREQUEST = _descriptor.Descriptor(
  name='ListServicesRequest',
  full_name='yamcs.protobuf.yamcsManagement.ListServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ListServicesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4061,
  serialized_end=4100,
)


_GETSERVICEREQUEST = _descriptor.Descriptor(
  name='GetServiceRequest',
  full_name='yamcs.protobuf.yamcsManagement.GetServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.GetServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.GetServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4102,
  serialized_end=4153,
)


_STARTSERVICEREQUEST = _descriptor.Descriptor(
  name='StartServiceRequest',
  full_name='yamcs.protobuf.yamcsManagement.StartServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.StartServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.StartServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4155,
  serialized_end=4208,
)


_STOPSERVICEREQUEST = _descriptor.Descriptor(
  name='StopServiceRequest',
  full_name='yamcs.protobuf.yamcsManagement.StopServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.StopServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.StopServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4210,
  serialized_end=4262,
)


_LISTSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListServicesResponse',
  full_name='yamcs.protobuf.yamcsManagement.ListServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='yamcs.protobuf.yamcsManagement.ListServicesResponse.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4264,
  serialized_end=4349,
)


_LISTINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListInstancesRequest',
  full_name='yamcs.protobuf.yamcsManagement.ListInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='yamcs.protobuf.yamcsManagement.ListInstancesRequest.filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4351,
  serialized_end=4389,
)


_LISTINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstancesResponse',
  full_name='yamcs.protobuf.yamcsManagement.ListInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yamcs.protobuf.yamcsManagement.ListInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4391,
  serialized_end=4480,
)


_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4718,
  serialized_end=4769,
)

_CREATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=719,
)

_CREATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateInstanceRequest',
  full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.template', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.templateArgs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.yamcsManagement.CreateInstanceRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY, _CREATEINSTANCEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4483,
  serialized_end=4816,
)


_LISTINSTANCETEMPLATESRESPONSE = _descriptor.Descriptor(
  name='ListInstanceTemplatesResponse',
  full_name='yamcs.protobuf.yamcsManagement.ListInstanceTemplatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templates', full_name='yamcs.protobuf.yamcsManagement.ListInstanceTemplatesResponse.templates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4818,
  serialized_end=4918,
)


_EDITINSTANCEREQUEST = _descriptor.Descriptor(
  name='EditInstanceRequest',
  full_name='yamcs.protobuf.yamcsManagement.EditInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.EditInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.EditInstanceRequest.state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4920,
  serialized_end=4974,
)


_LEAPSECONDSTABLE_VALIDITYRANGE = _descriptor.Descriptor(
  name='ValidityRange',
  full_name='yamcs.protobuf.yamcsManagement.LeapSecondsTable.ValidityRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.yamcsManagement.LeapSecondsTable.ValidityRange.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.yamcsManagement.LeapSecondsTable.ValidityRange.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leapSeconds', full_name='yamcs.protobuf.yamcsManagement.LeapSecondsTable.ValidityRange.leapSeconds', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taiDifference', full_name='yamcs.protobuf.yamcsManagement.LeapSecondsTable.ValidityRange.taiDifference', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5077,
  serialized_end=5165,
)

_LEAPSECONDSTABLE = _descriptor.Descriptor(
  name='LeapSecondsTable',
  full_name='yamcs.protobuf.yamcsManagement.LeapSecondsTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranges', full_name='yamcs.protobuf.yamcsManagement.LeapSecondsTable.ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LEAPSECONDSTABLE_VALIDITYRANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4977,
  serialized_end=5165,
)


_GETINSTANCETEMPLATEREQUEST = _descriptor.Descriptor(
  name='GetInstanceTemplateRequest',
  full_name='yamcs.protobuf.yamcsManagement.GetInstanceTemplateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.yamcsManagement.GetInstanceTemplateRequest.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5167,
  serialized_end=5213,
)


_GETINSTANCEREQUEST = _descriptor.Descriptor(
  name='GetInstanceRequest',
  full_name='yamcs.protobuf.yamcsManagement.GetInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.GetInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5215,
  serialized_end=5253,
)


_STARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='StartInstanceRequest',
  full_name='yamcs.protobuf.yamcsManagement.StartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.StartInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5255,
  serialized_end=5295,
)


_STOPINSTANCEREQUEST = _descriptor.Descriptor(
  name='StopInstanceRequest',
  full_name='yamcs.protobuf.yamcsManagement.StopInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.StopInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5297,
  serialized_end=5336,
)


_RESTARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='RestartInstanceRequest',
  full_name='yamcs.protobuf.yamcsManagement.RestartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.RestartInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5338,
  serialized_end=5380,
)


_LISTLINKSREQUEST = _descriptor.Descriptor(
  name='ListLinksRequest',
  full_name='yamcs.protobuf.yamcsManagement.ListLinksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ListLinksRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5382,
  serialized_end=5418,
)


_LISTLINKSRESPONSE = _descriptor.Descriptor(
  name='ListLinksResponse',
  full_name='yamcs.protobuf.yamcsManagement.ListLinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='links', full_name='yamcs.protobuf.yamcsManagement.ListLinksResponse.links', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5420,
  serialized_end=5496,
)


_GETLINKREQUEST = _descriptor.Descriptor(
  name='GetLinkRequest',
  full_name='yamcs.protobuf.yamcsManagement.GetLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.GetLinkRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.GetLinkRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5498,
  serialized_end=5546,
)


_EDITLINKREQUEST = _descriptor.Descriptor(
  name='EditLinkRequest',
  full_name='yamcs.protobuf.yamcsManagement.EditLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.EditLinkRequest.instance', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.EditLinkRequest.name', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.EditLinkRequest.state', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resetCounters', full_name='yamcs.protobuf.yamcsManagement.EditLinkRequest.resetCounters', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5548,
  serialized_end=5635,
)

_YAMCSINSTANCES.fields_by_name['instance'].message_type = _YAMCSINSTANCE
_YAMCSINSTANCE_LABELSENTRY.containing_type = _YAMCSINSTANCE
_YAMCSINSTANCE.fields_by_name['missionDatabase'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._MISSIONDATABASE
_YAMCSINSTANCE.fields_by_name['processor'].message_type = _PROCESSORINFO
_YAMCSINSTANCE.fields_by_name['state'].enum_type = _YAMCSINSTANCE_INSTANCESTATE
_YAMCSINSTANCE.fields_by_name['labels'].message_type = _YAMCSINSTANCE_LABELSENTRY
_YAMCSINSTANCE_INSTANCESTATE.containing_type = _YAMCSINSTANCE
_INSTANCETEMPLATE.fields_by_name['variable'].message_type = _TEMPLATEVARIABLE
_PROCESSORINFO.fields_by_name['state'].enum_type = _SERVICESTATE
_PROCESSORINFO.fields_by_name['replayRequest'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYREQUEST
_PROCESSORINFO.fields_by_name['replayState'].enum_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYSTATUS_REPLAYSTATE
_PROCESSORINFO.fields_by_name['service'].message_type = _SERVICEINFO
_CLIENTINFO.fields_by_name['state'].enum_type = _CLIENTINFO_CLIENTSTATE
_CLIENTINFO.fields_by_name['loginTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLIENTINFO_CLIENTSTATE.containing_type = _CLIENTINFO
_TMSTATISTICS.fields_by_name['lastReceived'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TMSTATISTICS.fields_by_name['lastPacketTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATISTICS.fields_by_name['tmstats'].message_type = _TMSTATISTICS
_STATISTICS.fields_by_name['lastUpdated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROCESSORMANAGEMENTREQUEST.fields_by_name['operation'].enum_type = _PROCESSORMANAGEMENTREQUEST_OPERATION
_PROCESSORMANAGEMENTREQUEST_OPERATION.containing_type = _PROCESSORMANAGEMENTREQUEST
_PROCESSORREQUEST.fields_by_name['operation'].enum_type = _PROCESSORREQUEST_OPERATION
_PROCESSORREQUEST.fields_by_name['replaySpeed'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYSPEED
_PROCESSORREQUEST_OPERATION.containing_type = _PROCESSORREQUEST
_LINKEVENT.fields_by_name['type'].enum_type = _LINKEVENT_TYPE
_LINKEVENT.fields_by_name['linkInfo'].message_type = _LINKINFO
_LINKEVENT_TYPE.containing_type = _LINKEVENT
_SERVICEINFO.fields_by_name['state'].enum_type = _SERVICESTATE
_STREAMEVENT.fields_by_name['type'].enum_type = _STREAMEVENT_TYPE
_STREAMEVENT_TYPE.containing_type = _STREAMEVENT
_SYSTEMINFO.fields_by_name['rootDirectories'].message_type = _ROOTDIRECTORY
_LISTSERVICESRESPONSE.fields_by_name['services'].message_type = _SERVICEINFO
_LISTINSTANCESRESPONSE.fields_by_name['instances'].message_type = _YAMCSINSTANCE
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST_LABELSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST.fields_by_name['templateArgs'].message_type = _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY
_CREATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _CREATEINSTANCEREQUEST_LABELSENTRY
_LISTINSTANCETEMPLATESRESPONSE.fields_by_name['templates'].message_type = _INSTANCETEMPLATE
_LEAPSECONDSTABLE_VALIDITYRANGE.containing_type = _LEAPSECONDSTABLE
_LEAPSECONDSTABLE.fields_by_name['ranges'].message_type = _LEAPSECONDSTABLE_VALIDITYRANGE
_LISTLINKSRESPONSE.fields_by_name['links'].message_type = _LINKINFO
DESCRIPTOR.message_types_by_name['YamcsInstances'] = _YAMCSINSTANCES
DESCRIPTOR.message_types_by_name['YamcsInstance'] = _YAMCSINSTANCE
DESCRIPTOR.message_types_by_name['InstanceTemplate'] = _INSTANCETEMPLATE
DESCRIPTOR.message_types_by_name['TemplateVariable'] = _TEMPLATEVARIABLE
DESCRIPTOR.message_types_by_name['ProcessorInfo'] = _PROCESSORINFO
DESCRIPTOR.message_types_by_name['ClientInfo'] = _CLIENTINFO
DESCRIPTOR.message_types_by_name['TmStatistics'] = _TMSTATISTICS
DESCRIPTOR.message_types_by_name['Statistics'] = _STATISTICS
DESCRIPTOR.message_types_by_name['ProcessorManagementRequest'] = _PROCESSORMANAGEMENTREQUEST
DESCRIPTOR.message_types_by_name['ProcessorRequest'] = _PROCESSORREQUEST
DESCRIPTOR.message_types_by_name['LinkInfo'] = _LINKINFO
DESCRIPTOR.message_types_by_name['LinkEvent'] = _LINKEVENT
DESCRIPTOR.message_types_by_name['ServiceInfo'] = _SERVICEINFO
DESCRIPTOR.message_types_by_name['StreamEvent'] = _STREAMEVENT
DESCRIPTOR.message_types_by_name['SystemInfo'] = _SYSTEMINFO
DESCRIPTOR.message_types_by_name['RootDirectory'] = _ROOTDIRECTORY
DESCRIPTOR.message_types_by_name['ListServicesRequest'] = _LISTSERVICESREQUEST
DESCRIPTOR.message_types_by_name['GetServiceRequest'] = _GETSERVICEREQUEST
DESCRIPTOR.message_types_by_name['StartServiceRequest'] = _STARTSERVICEREQUEST
DESCRIPTOR.message_types_by_name['StopServiceRequest'] = _STOPSERVICEREQUEST
DESCRIPTOR.message_types_by_name['ListServicesResponse'] = _LISTSERVICESRESPONSE
DESCRIPTOR.message_types_by_name['ListInstancesRequest'] = _LISTINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesResponse'] = _LISTINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateInstanceRequest'] = _CREATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceTemplatesResponse'] = _LISTINSTANCETEMPLATESRESPONSE
DESCRIPTOR.message_types_by_name['EditInstanceRequest'] = _EDITINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['LeapSecondsTable'] = _LEAPSECONDSTABLE
DESCRIPTOR.message_types_by_name['GetInstanceTemplateRequest'] = _GETINSTANCETEMPLATEREQUEST
DESCRIPTOR.message_types_by_name['GetInstanceRequest'] = _GETINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StartInstanceRequest'] = _STARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StopInstanceRequest'] = _STOPINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['RestartInstanceRequest'] = _RESTARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListLinksRequest'] = _LISTLINKSREQUEST
DESCRIPTOR.message_types_by_name['ListLinksResponse'] = _LISTLINKSRESPONSE
DESCRIPTOR.message_types_by_name['GetLinkRequest'] = _GETLINKREQUEST
DESCRIPTOR.message_types_by_name['EditLinkRequest'] = _EDITLINKREQUEST
DESCRIPTOR.enum_types_by_name['ServiceState'] = _SERVICESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YamcsInstances = _reflection.GeneratedProtocolMessageType('YamcsInstances', (_message.Message,), {
  'DESCRIPTOR' : _YAMCSINSTANCES,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.YamcsInstances)
  })
_sym_db.RegisterMessage(YamcsInstances)

YamcsInstance = _reflection.GeneratedProtocolMessageType('YamcsInstance', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _YAMCSINSTANCE_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.YamcsInstance.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _YAMCSINSTANCE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.YamcsInstance)
  })
_sym_db.RegisterMessage(YamcsInstance)
_sym_db.RegisterMessage(YamcsInstance.LabelsEntry)

InstanceTemplate = _reflection.GeneratedProtocolMessageType('InstanceTemplate', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCETEMPLATE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.InstanceTemplate)
  })
_sym_db.RegisterMessage(InstanceTemplate)

TemplateVariable = _reflection.GeneratedProtocolMessageType('TemplateVariable', (_message.Message,), {
  'DESCRIPTOR' : _TEMPLATEVARIABLE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.TemplateVariable)
  })
_sym_db.RegisterMessage(TemplateVariable)

ProcessorInfo = _reflection.GeneratedProtocolMessageType('ProcessorInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORINFO,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorInfo)
  })
_sym_db.RegisterMessage(ProcessorInfo)

ClientInfo = _reflection.GeneratedProtocolMessageType('ClientInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTINFO,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ClientInfo)
  })
_sym_db.RegisterMessage(ClientInfo)

TmStatistics = _reflection.GeneratedProtocolMessageType('TmStatistics', (_message.Message,), {
  'DESCRIPTOR' : _TMSTATISTICS,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.TmStatistics)
  })
_sym_db.RegisterMessage(TmStatistics)

Statistics = _reflection.GeneratedProtocolMessageType('Statistics', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICS,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.Statistics)
  })
_sym_db.RegisterMessage(Statistics)

ProcessorManagementRequest = _reflection.GeneratedProtocolMessageType('ProcessorManagementRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORMANAGEMENTREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorManagementRequest)
  })
_sym_db.RegisterMessage(ProcessorManagementRequest)

ProcessorRequest = _reflection.GeneratedProtocolMessageType('ProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorRequest)
  })
_sym_db.RegisterMessage(ProcessorRequest)

LinkInfo = _reflection.GeneratedProtocolMessageType('LinkInfo', (_message.Message,), {
  'DESCRIPTOR' : _LINKINFO,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.LinkInfo)
  })
_sym_db.RegisterMessage(LinkInfo)

LinkEvent = _reflection.GeneratedProtocolMessageType('LinkEvent', (_message.Message,), {
  'DESCRIPTOR' : _LINKEVENT,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.LinkEvent)
  })
_sym_db.RegisterMessage(LinkEvent)

ServiceInfo = _reflection.GeneratedProtocolMessageType('ServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINFO,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ServiceInfo)
  })
_sym_db.RegisterMessage(ServiceInfo)

StreamEvent = _reflection.GeneratedProtocolMessageType('StreamEvent', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEVENT,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.StreamEvent)
  })
_sym_db.RegisterMessage(StreamEvent)

SystemInfo = _reflection.GeneratedProtocolMessageType('SystemInfo', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMINFO,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.SystemInfo)
  })
_sym_db.RegisterMessage(SystemInfo)

RootDirectory = _reflection.GeneratedProtocolMessageType('RootDirectory', (_message.Message,), {
  'DESCRIPTOR' : _ROOTDIRECTORY,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.RootDirectory)
  })
_sym_db.RegisterMessage(RootDirectory)

ListServicesRequest = _reflection.GeneratedProtocolMessageType('ListServicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ListServicesRequest)
  })
_sym_db.RegisterMessage(ListServicesRequest)

GetServiceRequest = _reflection.GeneratedProtocolMessageType('GetServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.GetServiceRequest)
  })
_sym_db.RegisterMessage(GetServiceRequest)

StartServiceRequest = _reflection.GeneratedProtocolMessageType('StartServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.StartServiceRequest)
  })
_sym_db.RegisterMessage(StartServiceRequest)

StopServiceRequest = _reflection.GeneratedProtocolMessageType('StopServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.StopServiceRequest)
  })
_sym_db.RegisterMessage(StopServiceRequest)

ListServicesResponse = _reflection.GeneratedProtocolMessageType('ListServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESPONSE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ListServicesResponse)
  })
_sym_db.RegisterMessage(ListServicesResponse)

ListInstancesRequest = _reflection.GeneratedProtocolMessageType('ListInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ListInstancesRequest)
  })
_sym_db.RegisterMessage(ListInstancesRequest)

ListInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESRESPONSE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ListInstancesResponse)
  })
_sym_db.RegisterMessage(ListInstancesResponse)

CreateInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceRequest', (_message.Message,), {

  'TemplateArgsEntry' : _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY,
    '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.CreateInstanceRequest.TemplateArgsEntry)
    })
  ,

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.CreateInstanceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.CreateInstanceRequest)
  })
_sym_db.RegisterMessage(CreateInstanceRequest)
_sym_db.RegisterMessage(CreateInstanceRequest.TemplateArgsEntry)
_sym_db.RegisterMessage(CreateInstanceRequest.LabelsEntry)

ListInstanceTemplatesResponse = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCETEMPLATESRESPONSE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ListInstanceTemplatesResponse)
  })
_sym_db.RegisterMessage(ListInstanceTemplatesResponse)

EditInstanceRequest = _reflection.GeneratedProtocolMessageType('EditInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.EditInstanceRequest)
  })
_sym_db.RegisterMessage(EditInstanceRequest)

LeapSecondsTable = _reflection.GeneratedProtocolMessageType('LeapSecondsTable', (_message.Message,), {

  'ValidityRange' : _reflection.GeneratedProtocolMessageType('ValidityRange', (_message.Message,), {
    'DESCRIPTOR' : _LEAPSECONDSTABLE_VALIDITYRANGE,
    '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.LeapSecondsTable.ValidityRange)
    })
  ,
  'DESCRIPTOR' : _LEAPSECONDSTABLE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.LeapSecondsTable)
  })
_sym_db.RegisterMessage(LeapSecondsTable)
_sym_db.RegisterMessage(LeapSecondsTable.ValidityRange)

GetInstanceTemplateRequest = _reflection.GeneratedProtocolMessageType('GetInstanceTemplateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCETEMPLATEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.GetInstanceTemplateRequest)
  })
_sym_db.RegisterMessage(GetInstanceTemplateRequest)

GetInstanceRequest = _reflection.GeneratedProtocolMessageType('GetInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.GetInstanceRequest)
  })
_sym_db.RegisterMessage(GetInstanceRequest)

StartInstanceRequest = _reflection.GeneratedProtocolMessageType('StartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.StartInstanceRequest)
  })
_sym_db.RegisterMessage(StartInstanceRequest)

StopInstanceRequest = _reflection.GeneratedProtocolMessageType('StopInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.StopInstanceRequest)
  })
_sym_db.RegisterMessage(StopInstanceRequest)

RestartInstanceRequest = _reflection.GeneratedProtocolMessageType('RestartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.RestartInstanceRequest)
  })
_sym_db.RegisterMessage(RestartInstanceRequest)

ListLinksRequest = _reflection.GeneratedProtocolMessageType('ListLinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLINKSREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ListLinksRequest)
  })
_sym_db.RegisterMessage(ListLinksRequest)

ListLinksResponse = _reflection.GeneratedProtocolMessageType('ListLinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLINKSRESPONSE,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ListLinksResponse)
  })
_sym_db.RegisterMessage(ListLinksResponse)

GetLinkRequest = _reflection.GeneratedProtocolMessageType('GetLinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLINKREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.GetLinkRequest)
  })
_sym_db.RegisterMessage(GetLinkRequest)

EditLinkRequest = _reflection.GeneratedProtocolMessageType('EditLinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITLINKREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.EditLinkRequest)
  })
_sym_db.RegisterMessage(EditLinkRequest)


DESCRIPTOR._options = None
_YAMCSINSTANCE_LABELSENTRY._options = None
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY._options = None
_CREATEINSTANCEREQUEST_LABELSENTRY._options = None

_MANAGEMENTAPI = _descriptor.ServiceDescriptor(
  name='ManagementApi',
  full_name='yamcs.protobuf.yamcsManagement.ManagementApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5732,
  serialized_end=8218,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSystemInfo',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.GetSystemInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SYSTEMINFO,
    serialized_options=_b('\212\222\003\016\n\014/api/sysinfo'),
  ),
  _descriptor.MethodDescriptor(
    name='GetLeapSeconds',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.GetLeapSeconds',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LEAPSECONDSTABLE,
    serialized_options=_b('\212\222\003\023\n\021/api/leap-seconds'),
  ),
  _descriptor.MethodDescriptor(
    name='ListInstanceTemplates',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.ListInstanceTemplates',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTINSTANCETEMPLATESRESPONSE,
    serialized_options=_b('\212\222\003\031\n\027/api/instance-templates'),
  ),
  _descriptor.MethodDescriptor(
    name='GetInstanceTemplate',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.GetInstanceTemplate',
    index=3,
    containing_service=None,
    input_type=_GETINSTANCETEMPLATEREQUEST,
    output_type=_INSTANCETEMPLATE,
    serialized_options=_b('\212\222\003$\n\"/api/instance-templates/{template}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.ListInstances',
    index=4,
    containing_service=None,
    input_type=_LISTINSTANCESREQUEST,
    output_type=_LISTINSTANCESRESPONSE,
    serialized_options=_b('\212\222\003\020\n\016/api/instances'),
  ),
  _descriptor.MethodDescriptor(
    name='GetInstance',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.GetInstance',
    index=5,
    containing_service=None,
    input_type=_GETINSTANCEREQUEST,
    output_type=_YAMCSINSTANCE,
    serialized_options=_b('\212\222\003\033\n\031/api/instances/{instance}'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateInstance',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.CreateInstance',
    index=6,
    containing_service=None,
    input_type=_CREATEINSTANCEREQUEST,
    output_type=_YAMCSINSTANCE,
    serialized_options=_b('\212\222\003\023\032\016/api/instances:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='StartInstance',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.StartInstance',
    index=7,
    containing_service=None,
    input_type=_STARTINSTANCEREQUEST,
    output_type=_YAMCSINSTANCE,
    serialized_options=_b('\212\222\003!\032\037/api/instances/{instance}:start'),
  ),
  _descriptor.MethodDescriptor(
    name='StopInstance',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.StopInstance',
    index=8,
    containing_service=None,
    input_type=_STOPINSTANCEREQUEST,
    output_type=_YAMCSINSTANCE,
    serialized_options=_b('\212\222\003 \032\036/api/instances/{instance}:stop'),
  ),
  _descriptor.MethodDescriptor(
    name='RestartInstance',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.RestartInstance',
    index=9,
    containing_service=None,
    input_type=_RESTARTINSTANCEREQUEST,
    output_type=_YAMCSINSTANCE,
    serialized_options=_b('\212\222\003#\032!/api/instances/{instance}:restart'),
  ),
  _descriptor.MethodDescriptor(
    name='ListServices',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.ListServices',
    index=10,
    containing_service=None,
    input_type=_LISTSERVICESREQUEST,
    output_type=_LISTSERVICESRESPONSE,
    serialized_options=_b('\212\222\003\032\n\030/api/services/{instance}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetService',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.GetService',
    index=11,
    containing_service=None,
    input_type=_GETSERVICEREQUEST,
    output_type=_SERVICEINFO,
    serialized_options=_b('\212\222\003!\n\037/api/services/{instance}/{name}'),
  ),
  _descriptor.MethodDescriptor(
    name='StartService',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.StartService',
    index=12,
    containing_service=None,
    input_type=_STARTSERVICEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003\'\032%/api/services/{instance}/{name}:start'),
  ),
  _descriptor.MethodDescriptor(
    name='StopService',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.StopService',
    index=13,
    containing_service=None,
    input_type=_STOPSERVICEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003&\032$/api/services/{instance}/{name}:stop'),
  ),
  _descriptor.MethodDescriptor(
    name='ListLinks',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.ListLinks',
    index=14,
    containing_service=None,
    input_type=_LISTLINKSREQUEST,
    output_type=_LISTLINKSRESPONSE,
    serialized_options=_b('\212\222\003\030\n\026/api/links/{instance?}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetLink',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.GetLink',
    index=15,
    containing_service=None,
    input_type=_GETLINKREQUEST,
    output_type=_LINKINFO,
    serialized_options=_b('\212\222\003\036\n\034/api/links/{instance}/{name}'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLink',
    full_name='yamcs.protobuf.yamcsManagement.ManagementApi.UpdateLink',
    index=16,
    containing_service=None,
    input_type=_EDITLINKREQUEST,
    output_type=_LINKINFO,
    serialized_options=_b('\212\222\003!*\034/api/links/{instance}/{name}:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_MANAGEMENTAPI)

DESCRIPTOR.services_by_name['ManagementApi'] = _MANAGEMENTAPI

# @@protoc_insertion_point(module_scope)
